:
# suck.sh -- extract news with suck

NewsHost=news
EmptyOK=no

if tty -s
then
	DoPurge=no
else
	DoPurge=yes
fi

while [ ! -z "$1" ]
do
	case "$1" in
	-n)	NewsHost="$2" ; shift ;;
	-p)	DoPurge=yes ;;
	+p)	DoPurge=no ;;
	-e)	EmptyOK=yes ;;
	+e)	EmptyOK=no ;;
	-*)	echo "$0: Error: Unknown option $1" ; exit ;;
	*)	echo "$0: Error: Unknown parameter $1" ; exit ;;
	esac
	shift
done

sucknewsrc="sucknewsrc.$NewsHost"

if [ ! -f "$sucknewsrc" ]
then
	echo "$0: Error: no sucknewsrc for host $NewsHost"
	exit
fi

case `id` in
*news*) ;;
*)	echo "$0: Your id is not news" ; exit ;;
esac

. ${NEWSCONFIG-/usr/lib/news/bin/config}
PATH="$NEWSCTL/bin:$NEWSBIN/maint:$NEWSBIN:$NEWSPATH:$PATH:/usr/local/bin"
export PATH
umask 0

MailTarget=william

dir=/home/news/suck

if [ ! -d "$dir" ]
then
	echo "$0: Could not find the directory $dir"
	pwd | mail -s "$0: dir $dir not found" "$MailTarget"
	exit
fi

cd "$dir"

echo "Starting suck at `date`"
echo "  Command line is $0 $*"
echo "  Directory is `pwd`"
echo "  Id is `id`"
echo "  Host is $NewsHost"
echo "  DoPurge is $DoPurge"
echo "  EmptyOK is $EmptyOK"
echo

roll_rnews(){
	for dash in "-----" "----" "---" "--" "-" ""
	do
		if [ -f "rnews.txt$dash" ]
		then
			if [ -f "rnews.txt-$dash" ]
			then
				rm -f "rnews.txt-$dash"
			fi
			mv "rnews.txt$dash" "rnews.txt-$dash"
		fi
	done
	rm -f rnews.txt
}

# roll_rnews
# exit

if [ -f "sucksh.pid" ]
then
	echo "Warning: sucksh.pid exists"
	ls -l sucksh.pid
	cat sucksh.pid
	pid=`cat sucksh.pid`
	if [ ! -x "$pid" ]
	then
		line=`ps -h "$pid"`
		if [ -z "$line" ]
		then
			pid=
		else
			x=x
		fi
	fi
	if [ -z "$pid" ]
	then
		echo "Old suck process is no longer running"
	else
		echo "Aborting, suck.sh already running"
		ls -l sucksh.pid | mail -s "$0: suck.sh running" "$MailTarget"
		exit
	fi
fi

errors=

rm -f sucksh.pid

echo $$ > sucksh.pid

set -x

echo "Cleaning work areas"

# Directory for loading files
rm -rf files
if [ ! -d files ] ; then mkdir files ; fi

# Directory for work copies of config files
# Removing it prevents restarting

if [ "$DoPurge" = no ]
then
	echo "Leaving temp directory to allow a manual retry"
else
	rm -rf temp
fi

if [ ! -d temp ] ; then mkdir temp ; fi

# Remove old work files

rm -f mesg.txt
touch mesg.txt

roll_rnews

./agernews.sh

# Cycle old active file

if [ -f ${sucknewsrc}-3 ] ; then mv ${sucknewsrc}-3 ${sucknewsrc}-4 ; fi
if [ -f ${sucknewsrc}-2 ] ; then mv ${sucknewsrc}-2 ${sucknewsrc}-3 ; fi
if [ -f ${sucknewsrc}-1 ] ; then mv ${sucknewsrc}-1 ${sucknewsrc}-2 ; fi
if [ -f ${sucknewsrc} ] ; then cp ${sucknewsrc} ${sucknewsrc}-1 ; fi
if [ -f ${sucknewsrc}.old ] ; then cp ${sucknewsrc} ${sucknewsrc}.old- ; fi

echo "Disk space:"
df -k

echo "Checking news integrity"
if /usr/lib/newsbin/maint/newswatch
then
	x=x
else
	errors="$errors newswatch1-top"
fi

if [ "$DoPurge" = no ]
then
	echo "Interactive session, not expiring old news"
else
	echo "Expiring old news"
	if /usr/lib/newsbin/expire/doexpire
	then
		x=x
	else
		errors="$errors doexpire"
	fi

	echo "Updating article limits"
	if /usr/lib/newsbin/expire/upact
	then
		x=x
	else
		errors="$errors upact"
	fi

	echo "Rechecking news integrity"
	if /usr/lib/newsbin/maint/newswatch
	then
		x=x
	else
		errors="$errors newswatch2-upact"
	fi

	echo "Disk space:"
	df -k
fi

suck_ok=yes
got_rnews=no
last_suck_pass=0

# Directory for loading files
rm -rf files
if [ ! -d files ] ; then mkdir files ; fi

for suck_pass in 01 02 03 04 05 06 07 08 09 10
do
	echo "Sucking articles, pass $suck_pass"

	last_suck_pass=$suck_pass

	# Remove old work file
	roll_rnews

	# Cycle old debug logs
	if [ -f debug.suck ] ; then mv debug.suck debug.suck- ; fi
	if [ -f suck.log ] ; then mv suck.log suck.log- ; fi
	rm -f gmon.out

	# Make a suckargs file

	suckargs=suckargs
	if [ "$suck_pass" = 99 ]
	then
		echo "Adding -a to suckargs"
		suckargs99="$suckargs.99"
		rm -f "$suckargs99"
		cp "$suckargs" "$suckargs99"
		chmod +w "$suckargs99"
		echo "-a" >> "$suckargs99"
		suckargs="$suckargs99"
	fi

	if suck "$NewsHost" -p ".$NewsHost" @$suckargs
	then
		suck_ok=yes
	else
		suck_ok=no
		echo "$0: Warning: suck might have failed, status $?"
	fi

	if [ "$suck_ok" = no -a "$EmptyOK" = yes -a ! -f rnews.txt ]
	then
		suck_ok=yes
		echo "$0: Warning: stopping after empty file"
	fi

	if [ -f gmon.out ]
	then
		echo
		echo "Profiling suck..."
		echo
		gprof /usr/local/bin/suck
		echo
	fi

	if [ ! -f rnews.txt ]
	then
		echo "No rnews.txt created for pass $suck_pass, nothing to do"
	else
		got_rnews=yes

		rnews="rnews-`date +%Y%m%d%H%M`-${suck_pass}"

		if mv rnews.txt "$rnews"
		then
			x=x
		else
			errors="$errors mv-rnews"
		fi

		if [ ! -f "$rnews" ]
		then
			errors="$errors mv-$rnews-missing"
		fi

		echo "Created news batch file for pass $suck_pass"
		ls -l "$rnews"
		ls -l "$rnews" >> mesg.txt

		echo "Copying the batch with rnews"
		if /usr/lib/newsbin/input/rnews < "$rnews"
		then
			x=x
		else
			errors="$errors rnews"
		fi

		echo "Compressing news"

		if gzip -v9 "$rnews"
		then
			x=x
		else
			errors="$errors gzip-failed"
		fi

		if [ -f "$rnews.gz" -a ! -f "$rnews" ]
		then
			rnews="$rnews.gz"
		else
			errors="$errors gzip-no-gz"
		fi

		echo "Copying news"
#		-C = copy
#		-d = make directories
#		-n "$MailTarget" = mail when copied
		if uucp -C -d "$rnews" owl486\!/usr/spool/uucppublic/news/$rnews
		then
			x=x
		else
			errors="$errors uucp"
		fi

		echo "Updating the batch with newsrun"
		if /usr/lib/newsbin/input/newsrun
		then
			x=x
		else
			errors="$errors newsrun"
		fi

		echo "Rechecking news integrity"
		if /usr/lib/newsbin/maint/newswatch
		then
			x=x
		else
			errors="$errors newswatch3-newsrun"
		fi
	fi

	if [ "$suck_ok" = yes ]
	then
		echo "All articles downloaded after pass $suck_pass"
		break
	fi

	if [ "$DoPurge" = no ]
	then
		echo "Interactive session, not pausing"
	else
		echo "Pausing before retry"
		sleep 180
	fi	
done

if [ "$DoPurge" = no ]
then
	echo "Interactive session, not rolling logs"
else
	echo "Rolling daily news logs"
	if /usr/lib/newsbin/maint/newsdaily
	then
		x=x
	else
		errors="$errors newsdaily"
	fi

	echo "Rechecking news integrity"
	if /usr/lib/newsbin/maint/newswatch
	then
		x=x
	else
		errors="$errors newswatch4-newsdaily"
	fi
fi

echo "Disk space:"
df -k

mesg="Finished suck $NewsHost at `date`"

echo "$mesg"
echo "$mesg" >> mesg.txt

echo "ok: $suck_ok got_rnews: $got_rnews last_pass: $last_suck_pass" >> mesg.txt

#echo "suck_ok: $suck_ok" >> mesg.txt
#echo "got_rnews: $got_rnews" >> mesg.txt
#echo "last_suck_pass: $last_suck_pass" >> mesg.txt

if [ ! -z "$errors" ] ; then echo "errors: $errors" >> mesg.txt ; fi

# echo "suck.log:" >> mesg.txt
# cat suck.log >> mesg.txt

cat mesg.txt >> mesgall.txt

# mail -s "$mesg" "$MailTarget" < mesg.txt

rm -f sucksh.pid
